==> ogre-next-2.2.4-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_default_shadow_camera_setup.js <==
var class_ogre_1_1_default_shadow_camera_setup =
[
    [ "DefaultShadowCameraSetup", "class_ogre_1_1_default_shadow_camera_setup.html#a33706dc2e3d61f4f0b2419d9cc259c76", null ],
    [ "~DefaultShadowCameraSetup", "class_ogre_1_1_default_shadow_camera_setup.html#a4663dca3e570aa2e7f0134c9221ad6ea", null ],
    [ "getMaxDistance", "class_ogre_1_1_default_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b", null ],
    [ "getMinDistance", "class_ogre_1_1_default_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19", null ],
    [ "getShadowCamera", "class_ogre_1_1_default_shadow_camera_setup.html#a5e701a58a1dbd0a22810faec87e9a59a", null ],
    [ "operator delete", "class_ogre_1_1_default_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_default_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_default_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_default_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_default_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_default_shadow_camera_setup.html#ac4bdf968b7b9af8a5239a27da73d5711", null ],
    [ "operator new", "class_ogre_1_1_default_shadow_camera_setup.html#a421b197ca3a38da17e2eb1531a645fa2", null ],
    [ "operator new", "class_ogre_1_1_default_shadow_camera_setup.html#ab78a921e54419be677839cdf15d1f0b8", null ],
    [ "operator new[]", "class_ogre_1_1_default_shadow_camera_setup.html#afa2943846ba6a2b5824a12857139cf5e", null ],
    [ "operator new[]", "class_ogre_1_1_default_shadow_camera_setup.html#a4be37baef81876985aa1071ad5acc6dd", null ]
];

==> ogre-next-2.3.0-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/class_ogre_1_1_default_shadow_camera_setup.js <==
var class_ogre_1_1_default_shadow_camera_setup =
[
    [ "DefaultShadowCameraSetup", "class_ogre_1_1_default_shadow_camera_setup.html#a33706dc2e3d61f4f0b2419d9cc259c76", null ],
    [ "~DefaultShadowCameraSetup", "class_ogre_1_1_default_shadow_camera_setup.html#a4663dca3e570aa2e7f0134c9221ad6ea", null ],
    [ "getMaxDistance", "class_ogre_1_1_default_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b", null ],
    [ "getMinDistance", "class_ogre_1_1_default_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19", null ],
    [ "getShadowCamera", "class_ogre_1_1_default_shadow_camera_setup.html#a5e701a58a1dbd0a22810faec87e9a59a", null ],
    [ "operator delete", "class_ogre_1_1_default_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded", null ],
    [ "operator delete", "class_ogre_1_1_default_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792", null ],
    [ "operator delete", "class_ogre_1_1_default_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144", null ],
    [ "operator delete[]", "class_ogre_1_1_default_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c", null ],
    [ "operator delete[]", "class_ogre_1_1_default_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d", null ],
    [ "operator new", "class_ogre_1_1_default_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9", null ],
    [ "operator new", "class_ogre_1_1_default_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b", null ],
    [ "operator new", "class_ogre_1_1_default_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023", null ],
    [ "operator new[]", "class_ogre_1_1_default_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c", null ],
    [ "operator new[]", "class_ogre_1_1_default_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7", null ],
    [ "setUseEsm", "class_ogre_1_1_default_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536", null ]
];
